@@ -409,7 +409,7 @@ class Interaction:
         )
         # Ephemeral messages aren't stored and can't be deleted or edited
         # Same for empty type-1 & type-5 messages
-        if ephemeral or (content is None and embed is None):
+        if ephemeral or is_empty_message:
             return None
         self.editable = True
         if delete_after is not None:
