@@ -889,6 +889,41 @@ class SlashClient:
             )
         )
 
+    async def delete_global_commands(self, ignore_errors=False):
+        """
+        Deletes all global commands.
+
+        Parameters
+        ----------
+        ignore_errors : bool
+            if set to ``True``, the method doesn't get interrupted by unexpected errors
+        """
+        for cmd in self.registered_global_commands:
+            try:
+                await self.delete_global_command(cmd.id)
+            except Exception as e:
+                if not ignore_errors:
+                    raise e
+
+    async def delete_guild_commands(self, guild_id: int, ignore_errors=False):
+        """
+        Deletes all local commands in the specified guild.
+
+        Parameters
+        ----------
+        guild_id : int
+            the ID of the guild where you're going to delete the commands
+        ignore_errors : bool
+            if set to ``True``, the method doesn't get interrupted by unexpected errors
+        """
+        cmds = await self.fetch_guild_commands(guild_id)
+        for cmd in cmds:
+            try:
+                await self.delete_guild_command(guild_id, cmd.id)
+            except Exception as e:
+                if not ignore_errors:
+                    raise e
+
     # Even slower API methods
     async def fetch_global_command_named(self, name: str):
         '''
